@@ -72,14 +72,8 @@ QGeoMappingManagerEngineCm::QGeoMappingManagerEngineCm(const QMap<QString, QVari
     setSupportedMapTypes(types);
 
     m_nam = new QNetworkAccessManager(this);
-    m_cache = new QNetworkDiskCache(this);
-
-    QDir dir = QDir::temp();
-    dir.mkdir("maptiles-cm");
-    dir.cd("maptiles-cm");
-
-    m_cache->setCacheDirectory(dir.path());
-    DBG_CM(TILES_M, INFO_L, "Setting cache dir to " << dir.path());
+    //m_cache = new QNetworkDiskCache(this);
+    m_cacheSize = DEFAULT_TILE_CACHE_SIZE;
 
     QList<QString> keys = m_parameters.keys();
 
@@ -98,41 +92,43 @@ QGeoMappingManagerEngineCm::QGeoMappingManagerEngineCm(const QMap<QString, QVari
     if (keys.contains("mapping.cache.directory")) {
         QString cacheDir = m_parameters.value("mapping.cache.directory").toString();
         if (!cacheDir.isEmpty())
-            m_cache->setCacheDirectory(cacheDir);
+            m_cacheDir = cacheDir;
+            //m_cache->setCacheDirectory(cacheDir);
     }
+    else
+    {
+        // set default cache dir
+        QDir dir = QDir::temp();
+        dir.mkdir(DEFAULT_TILE_CACHE_DIR);
+        dir.cd(DEFAULT_TILE_CACHE_DIR);
+        //m_cache->setCacheDirectory(dir.path());
+        m_cacheDir = dir.path();
+    }
+    DBG_CM(TILES_M, INFO_L, "Setting tile cache dir to " << m_cacheDir);
 
     if (keys.contains("mapping.cache.size")) {
         bool ok = false;
         qint64 cacheSize = m_parameters.value("mapping.cache.size").toString().toLongLong(&ok);
-        if (ok)
-            m_cache->setMaximumCacheSize(cacheSize);
+        if (ok) {
+            //m_cache->setMaximumCacheSize(cacheSize);
+            m_cacheSize = cacheSize;
+            DBG_CM(TILES_M, INFO_L, "Setting tile cache size = " << m_cacheSize);
+        }
     }
 
-    m_nam->setCache(m_cache);
+    //m_nam->setCache(m_cache);
+    if (m_cacheSize > 0) cleanCacheToSize(m_cacheSize);
 }
 
-QGeoMappingManagerEngineCm::~QGeoMappingManagerEngineCm() {}
+QGeoMappingManagerEngineCm::~QGeoMappingManagerEngineCm()
+{
+    // 0 - means unlimited cache, no cleaning!
+    if (m_cacheSize > 0) cleanCacheToSize(m_cacheSize);
+}
 
 QGeoTiledMapReply* QGeoMappingManagerEngineCm::getTileImage(const QGeoTiledMapRequest &request)
 {
-    QString rawRequest = getRequestString(request);
-
-	DBG_CM(TILES_M, INFO_L, "tileURL:" << rawRequest );
-
-    QNetworkRequest netRequest = QNetworkRequest(QUrl(rawRequest));
-    netRequest.setAttribute(QNetworkRequest::CacheLoadControlAttribute, QNetworkRequest::PreferCache);
-    QString ua = QFileInfo(QApplication::applicationFilePath()).fileName();
-    ua.remove(QChar('"'), Qt::CaseInsensitive);
-    ua += " (Qt";
-    ua += qVersion();
-    ua += " QtMobility 1.1 ) cm GeoSearchManager";
-    netRequest.setRawHeader("User-Agent", ua.toAscii());
-    m_cache->metaData(netRequest.url()).setLastModified(QDateTime::currentDateTime());
-
-    QNetworkReply* netReply = m_nam->get(netRequest);
-
-    QGeoTiledMapReply* mapReply = new QGeoMapReplyCm(netReply, request, this);
-
+    QGeoTiledMapReply* mapReply = new QGeoMapReplyCm(/*netReply*/ 0, request, this);
     return mapReply;
 }
 
@@ -160,3 +156,36 @@ QString QGeoMappingManagerEngineCm::getRequestString(const QGeoTiledMapRequest &
     return requestString;
 }
 
+void QGeoMappingManagerEngineCm::cleanCacheToSize(int sizeLimit)
+{
+    DBG_CM(TILES_M, INFO_L, "cleanCacheToSize():  start cleaning cache, sizeLimit = " << sizeLimit);
+
+    QDir dir;
+    dir.cd(m_cacheDir);
+
+    QStringList filters;
+    filters << "*.png";
+    dir.setNameFilters(filters);
+    dir.setSorting(QDir::Time);
+
+    qint64 totalSize = 0;   // SUM of all tiles size (not precize cache size, because of cluster size)
+    QFileInfoList list = dir.entryInfoList();
+    for (int i = 0; i < list.size(); ++i) {
+        totalSize += list.at(i).size();
+        //QFileInfo fileInfo = list.at(i);
+        //qDebug() << fileInfo.lastModified() << "    " << fileInfo.fileName() << "    " << fileInfo.size();
+    }
+    DBG_CM(TILES_M, INFO_L, "Current cache size in bytes = " << totalSize);
+
+    // start cleaning:
+    int listSize = list.size();
+    while ((listSize > 0) && (totalSize > sizeLimit)) {
+        totalSize -= list.at(listSize-1).size();
+        if (!dir.remove(list.at(listSize-1).fileName())) {
+            DBG_CM(TILES_M, ERR_L, "Failed to delete file: " << list.at(listSize-1).fileName());
+            totalSize += list.at(listSize-1).size();
+        }
+        listSize--;
+    }
+    DBG_CM(TILES_M, INFO_L, "Cache cleaning finished, current cache size = " << totalSize);
+}
