@@ -3,6 +3,7 @@
 
 #include <QNetworkReply>
 #include <QMenu>
+#include <QVBoxLayout>
 #include <QGeoBoundingBox>
 QTM_USE_NAMESPACE
 
@@ -18,7 +19,7 @@ class CacheProviderPlugin {
   virtual void processRequestInfo(const QString &) = 0;
   virtual void processRequestDetail(const QString &) = 0;
   virtual void setCacheProvider(CacheProvider*) = 0;
-  virtual void createMenu(QMenu*) = 0;
+  virtual void createConfig(QDialog *, QVBoxLayout*) = 0;
 
   public slots:
   virtual void replyFinished(QNetworkReply*) = 0;
