@@ -1,6 +1,7 @@
 #ifndef CACHEWINDOW_H
 #define CACHEWINDOW_H
 
+#include "locationprovider.h"
 #include "customwindow.h"
 #include "cache.h"
 #include "iconloader.h"
@@ -10,17 +11,19 @@ class CacheWindow : public CustomWindow {
   Q_OBJECT;
 
  public:
-  CacheWindow(const Cache &, QWidget * = 0);
+  CacheWindow(const Cache &, LocationProvider *, QWidget * = 0);
   ~CacheWindow();
 
  private slots:
   void showDescription();
+  void showNavigation();
   void showHint();
   void openCacheUrl();
 
  private:
   Cache m_cache;
   IconLoader m_iconLoader;
+  LocationProvider *m_locationProvider;
 };
 
 #endif
