@@ -1,4 +1,7 @@
 #include <QApplication>
+#include <QTranslator>
+#include <QDir>
+#include <QLocale>
 
 #include "mainwindow.h"
 #include "locationprovider.h"
@@ -37,7 +40,8 @@ int main(int argc, char **argv) {
 
   LocationProvider locationProvider;
 
-  MainWindow window(&locationProvider);
-  window.show();
+  MainWindow *mainWindow = new MainWindow(&locationProvider);
+  mainWindow->show();
+
   return app.exec();
 }
